@@ -10,7 +10,11 @@ from ..data import Data
 from ..dump import Record
 from ..exceptions import InsufficientMemoryError
 from ._bitfield import BitField, bitfield
-from ._meta import BitFieldsMeta
+from ._meta import BitFieldsMeta, ByteOrderHint
+
+BitField.__module__ = "plum.bitfields"
+bitfield.__module__ = "plum.bitfields"
+BitFieldsMeta.__module__ = "plum.bitfields"
 
 CLS = TypeVar("CLS", bound="BitFields")
 
@@ -22,7 +26,7 @@ class BitFields(
     """Bit fields data store type."""
 
     # filled in by metaclass
-    __byteorder__: str = "little"
+    __byteorder__: ByteOrderHint = "little"
     __compare_mask__: int = 0xFFFFFFFF
     __fields__: Dict = dict()
     __default__: int = 0
