@@ -15,7 +15,11 @@ class OptionalX(Transform):
 
     def __init__(self, *, fmt: Any, name: Optional[str] = None) -> None:
         if name is None:
-            name = f"Optional[{fmt.name}]"
+            if isinstance(fmt, Transform):
+                name = f"Optional[{fmt.name}]"
+            else:
+                # must be a structure or bitfields
+                name = f"Optional[{fmt.__name__}]"
 
         super().__init__(name)
 
